package Chart::Clicker::Decoration::Base;
use strict;

use base 'Chart::Clicker::Drawing::Component';

=head1 NAME

Chart::Clicker::Decoration::Base

=head1 DESCRIPTION

Chart::Clicker::Decoration::Base.

=head1 SYNOPSIS

=head1 METHODS

=head2 Constructor

=over 4

=item new

Creates a new Chart::Clicker::Decoration::Base.

=back

=head2 Class Methods

=over 4

=back

=head1 AUTHOR

Cory 'G' Watson <gphat@cpan.org>

=head1 SEE ALSO

perl(1)

=cut
1;
